#!/usr/bin/env python
# -*- coding: utf-8 -*-

from threading import Thread
from time import sleep

from PyQt4.QtCore import QObject, pyqtSignal, QSize, Qt
from PyQt4.QtGui import QApplication, QMainWindow, QLabel, QPixmap
import autopy


WIDTH, HEIGHT = 125, 100  # Ancho y Alto


class GetPosSignal(QObject):
    
    trigger = pyqtSignal()
    
    def __init__(self, capture_screen):
        QObject.__init__(self)
        self.capture_screen = capture_screen
    
    def connect(self):
        self.trigger.connect(self.get_pos)
    
    def get_pos(self):
        # Posición del cursor
        x, y = autopy.mouse.get_pos()
        # Crear un rectángulo alrededor de la posición obtenida
        self.capture_screen(x - (WIDTH / 2.), y - (HEIGHT / 2.))


class Window(QMainWindow):
    
    def __init__(self):
        QMainWindow.__init__(self)
        self.resize(WIDTH, HEIGHT)
        self.setWindowTitle("Ampliador PyQt y AutoPy")
        
        self.image_label = QLabel(self)
        self.setCentralWidget(self.image_label)
        self.setWindowFlags(Qt.WindowStaysOnTopHint)  # Mantener la ventana al frente
        
        self.signal = GetPosSignal(self.capture_screen)
        self.signal.connect()
        
        self.run = True
        Thread(target=self.worker).start()
    
    def closeEvent(self, event):
        # Terminar el thread al cerrar la ventana
        self.run = False
    
    def worker(self):
        while self.run:
            self.signal.trigger.emit()
            sleep(0.1)
    
    def capture_screen(self, x, y):
        # Capturar pantalla
        pixmap = QPixmap.grabWindow(
            QApplication.desktop().winId(), x, y, WIDTH, HEIGHT
        )
        # Aumentar 100%
        self.image_label.setPixmap(
            pixmap.scaled(QSize(WIDTH * 2, HEIGHT * 2))
        )


if __name__ == "__main__":
    app = QApplication([])
    window = Window()
    window.show()
    app.exec_()
